@@ -3,7 +3,7 @@
 
 /***************************************************************************
  *
- * Copyright (C) 2018-2023 - ZmartZone Holding BV - www.zmartzone.eu
+ * Copyright (C) 2018-2024 - ZmartZone Holding BV - www.zmartzone.eu
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License as
@@ -314,8 +314,7 @@ typedef struct oauth2_cfg_openidc_t {
 		dst = type##_init(log);
 
 #define _OAUTH2_CFG_CTX_CLONE_END                                              \
-	end:                                                                   \
-	return dst;                                                            \
+	end : return dst;                                                      \
 	}
 
 #define _OAUTH2_CFG_CTX_FREE_START(type)                                       \
